import {makeStyles, MenuItem, MenuList, Text, tokens} from "@fluentui/react-components";
import {ArchiveRegular, DocumentBulletListRegular, FolderRegular} from "@fluentui/react-icons";
import {VirtualizerScrollView} from "@fluentui/react-components/unstable";
import React from "react";
import {useStoreBucket} from "../../store/bucket";
import {Bucket, S3File} from "../../interfaces/connection";
import {useStoreFile} from "../../store/file";
import {useStoreConnection} from "../../store/connection";

const useStyles = makeStyles({
    container: {
        marginTop: '0.5rem',
        maxWidth: 'calc(100vw - 25rem - 1px)',
    },
    row: {
        height: '32px',
        display: 'flex',
        marginLeft: '0.5rem',
        marginRight: '0.5rem',
    },
    item: {
        width: '100%',
        maxWidth: '100%',
        "&:hover": {
            color: tokens.colorNeutralForeground2BrandPressed,
        }
    },
    text: {
        overflow: 'hidden',
        width: 'calc(100vw - 32rem)',
        display: "block",
    }
})

export function ListFileComponent() {

    const styles = useStyles();
    const {conn_active} = useStoreConnection();
    const {bucket_active} = useStoreBucket()
    const {prefix, files_get, files_list} = useStoreFile()

    async function handleClick(item: S3File) {
        if (item.type === 1) {
            console.log(`[DEBUG] click prefix = ${prefix} item.key = ${item.key}`)
            files_get(conn_active!, bucket_active!, prefix + item.key)
            return
        }
    }

    function handleRightClick(e: React.MouseEvent<HTMLDivElement>, item: S3File) {
        e.preventDefault()
    }

    return <MenuList className={styles.container}>
        <VirtualizerScrollView
            numItems={files_list.length}
            itemSize={32}
            container={{role: 'list', style: {maxHeight: 'calc(100vh - 9rem)'}}}
        >
            {(idx) => {
                return <div
                    className={styles.row} key={idx}
                    onClick={async () => {
                        await handleClick(files_list[idx])
                    }}
                    onContextMenu={async (e) => {
                        handleRightClick(e, files_list[idx])
                    }}>
                    <MenuItem className={styles.item}
                              icon={files_list[idx].type ? <FolderRegular/> : <DocumentBulletListRegular/>}>
                        <Text truncate wrap={false} className={styles.text}>
                            {files_list[idx].name}
                        </Text>
                    </MenuItem>
                </div>
            }}
        </VirtualizerScrollView>
    </MenuList>
}