import {create} from 'zustand'
import {Bucket, Connection, S3File} from "../interfaces/connection";
import {Dial, Resp} from "../api";

interface StoreFile {
    prefix: string;
    files_list: S3File[];
    files_get: (conn: Connection, bucket: Bucket, prefix: string) => void;
}

export const useStoreFile = create<StoreFile>()((set) => ({
    prefix: "",
    files_list: [],
    files_get: async (conn: Connection, bucket: Bucket, prefix = '') => {
        const res = await Dial<{ list: S3File[] }>('/api/bucket/files', {
            conn_id: conn.id,
            bucket: bucket.name,
            prefix: prefix ,
        })

        if (res.status !== 200) {
            return
        }

        set(state => {
            return {prefix: prefix, files_list: res.data.list}
        })
    }
}))
